.. _listeners:

Listeners
=========

Configuration sections that define listeners. These are usually the network interfaces that a DHCPv6
server listens on, like the well-known multicast address on an interface, or a unicast address where a
DHCPv6 relay can send its requests to.

.. toctree::

    listen-interface
    listen-unicast
